==> ulyxex.0.1.5.with-tinyMce.zip: pages/view_page.php <==
<?php
/* Ulyxex version 0.1.5 *****************/
if (!isset($index)) exit("not allowed");
$o_admin = New Ulyxex();
if (!is_numeric($paramId)){ 
	if (substr($paramId,0,4) == "link"){ // if not numeric and is a link		
		$paramId = $h->num(substr($paramId,4)); 
		require_once("pages/view_link.php");
		exit();
	} else { // if not numeric and not link goto to home
		$vals = $o_admin->home_params();
		$paramId = $vals['PAGEID'];
	}
} // else is a regular id page
/****************************************/
/* page elements						*/
require_once("core/view_page.php");
$pg_params = $o_admin->page_params($paramId);
$o_pag = new ViewPage($paramId,$pg_params['SORTSTYLE']);
$o_tree = new Tree();

$css = $h->css("css/".VIEWCSS,"external");
$ico = $h->ico("favicon.png");
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$title = $h->title(strip_tags($pg_params['NAME']));
$head = $h->head($ico.$meta.$css.$title);

$topPage = $o_tree->pagesNavigation($paramId);
$topPage .= $h->div($pg_params['DESCRIPTION'],"class='pagedescription'");

$bottomPage = $h->p($o_pag->next_pages,"class='pagenumbers'");

$bottomPage .= $h->p($h->ahref("index.php?k=page&amp;v=".$paramId,$t->wr("page")."url"),"class='pageurl'");
$bottomPage .= $h->uCredits();
/****************************************/
/* page data							*/	
$data = $o_pag->page_data;
/****************************************/
/* show									*/
$body = $h->body($topPage.$data.$bottomPage,"id='page".$paramId."'");
$page = $h->html5($head.$body);

echo $page;
?>

==> ulyxex.1.1.0.with-tinyMce.zip: pages/view_page.php <==
<?php
/* Ulyxex version 1.1.0 *****************/
if (!isset($index)) exit("not allowed");
$o_admin = New Ulyxex();
if (!is_numeric($paramId)){ 
	if (substr($paramId,0,4) == "link"){ // if not numeric and is a link		
		$paramId = $h->num(substr($paramId,4)); 
		require_once("pages/view_link.php");
		exit();
	} else { // if not numeric and not link goto to home
		$vals = $o_admin->home_params();
		$paramId = $vals['PAGEID'];
	}
} // else is a regular id page
/****************************************/
/* page elements						*/
require_once("core/view_page.php");
$pg_params = $o_admin->page_params($paramId);
$o_pag = new ViewPage($paramId,$pg_params['SORTSTYLE']);
$o_tree = new Tree();

$css = $h->css("css/".VIEWCSS,"external");
$ico = $h->ico("favicon.png");
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$title = $h->title(strip_tags($pg_params['NAME']));
$pageHead = $pg_params ['PAGEHEAD'];
$head = $h->head($ico.$meta.$css.$title.$pageHead);

$topPage = $h->div($o_tree->pagesNavigation($paramId));
$topPage .= $h->div($pg_params['DESCRIPTION'],"class='pagedescription'");

$bottomPage = $h->p($o_pag->next_pages,"class='pagenumbers'");

$bottomPage .= $h->p($h->ahref("index.php?k=page&amp;v=".$paramId,$t->wr("page")."url"),"class='pageurl'");
$bottomPage .= $h->uCredits();
/****************************************/
/* page data							*/	
$data = $o_pag->page_data;
/****************************************/
/* show									*/
$body = $h->body($topPage.$data.$bottomPage,"id='page".$paramId."'");
$page = $h->html5($head.$body);

echo $page;
?>
